@@ -41,8 +41,13 @@ galleryCreate <- function(gallery, dir){
     scripts <- c(scripts,"d3.layout.cloud.js")
   }
   if(!is.null(gallery$options$tutorial) && !identical(as.logical(gallery$options$tutorial),FALSE)){
-    scripts <- c(scripts,"tutorial.js",paste0("tutorial_",language))
-    styles <- c(styles,"tutorial.css")
+    if(mode==2){
+      scripts <- c(scripts,"tutorial2.js",paste0("tutorial2_",language))
+      styles <- c(styles,"tutorial2.css")
+    }else{
+      scripts <- c(scripts,"tutorial.js",paste0("tutorial_",language))
+      styles <- c(styles,"tutorial.css")
+    }
   }
   createHTML(dir, styles, scripts, function(){ return(imgWrapper(gallery,galleryJSON,dir)) },mode-1)
   if(mode==1 && is.null(gallery$options$note)){
@@ -146,7 +151,8 @@ gallery_rd3 <- function(nodes, name = NULL, label = NULL, color = NULL,
 
 gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
     order = NULL, decreasing = FALSE, ntext = NULL, mainframeHeight = NULL,
-    image = NULL, zoom = NULL, main = NULL, note = NULL, export = FALSE,
+    mainframeWidth = NULL, image = NULL, zoom = NULL, main = NULL, note = NULL,
+    frequencies = FALSE, tutorial = FALSE, tableButton = FALSE, export = FALSE,
     colorScheme = 0, language = c("en", "es", "ca"), dir = NULL){
 
   if(is.null(name)){
@@ -174,10 +180,19 @@ gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
   }
 
   if(!is.null(mainframeHeight)){
-    if(!(is.numeric(mainframeHeight) && mainframeHeight>=0.1 && mainframeHeight<=1)){
-      warning("mainframeHeight: must be numeric between 0.1 and 1")
+    if(!is.numeric(mainframeHeight)){
+      warning("mainframeHeight: must be numeric")
+    }else{
+      options[["mainframeHeight"]] <- mainframeHeight
+    }
+  }
+
+  if(!is.null(mainframeWidth)){
+    if(!is.numeric(mainframeWidth)){
+      warning("mainframeWidth: must be numeric")
+    }else{
+      options[["mainframeWidth"]] <- mainframeWidth
     }
-    options[["mainframeHeight"]] <- mainframeHeight
   }
 
   if(!is.null(zoom)){
@@ -190,7 +205,10 @@ gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
   if (!is.null(main)) options[["main"]] <- main
   if (!is.null(note)) options[["note"]] <- note
 
+  options <- showSomething(options,"tutorial",tutorial)
+  options <- showSomething(options,"showTable",tableButton)
   options <- showSomething(options,"exportExcel",export)
+  options <- showSomething(options,"frequencies",frequencies)
   options[["colorScheme"]] <- as.numeric(colorScheme)
   options[["language"]] <- checkLanguage(language)
 
@@ -304,6 +322,19 @@ treeGalleryWrapper <- function(tree, deep, initialType, tableformat, gallery_mod
   nodes <- nodes[!is.na(nodes)]
   nodes <- data.frame(name=nodes)
 
+  check_ids <- function(treeids,nodesids){
+      if(!length(intersect(nodesids,treeids))){
+        warning("nodes: no nodes matches the tree")
+      }else{
+        if(length(setdiff(treeids,nodesids))){
+          warning("nodes: some tree ids are missing in nodes")
+        }
+        if(length(setdiff(nodesids,treeids))){
+          warning("nodes: some nodes are missing in tree")
+        }
+      }
+  }
+
   if(!is.null(arguments$nodes)){
     name <- arguments$name
     if(is.data.frame(arguments$nodes)){
@@ -311,6 +342,7 @@ treeGalleryWrapper <- function(tree, deep, initialType, tableformat, gallery_mod
         name <- colnames(arguments$nodes)[1]
       }
       colnames(nodes)[1] <- name
+      check_ids(nodes[[name]],arguments$nodes[[name]])
       nodeorder <- c(intersect(arguments$nodes[[name]],nodes[[name]]),setdiff(nodes[[name]],arguments$nodes[[name]]))
       nodes <- merge(nodes, arguments$nodes, by=name, all.x=TRUE)
     }else if(is.list(arguments$nodes)){
@@ -334,6 +366,7 @@ treeGalleryWrapper <- function(tree, deep, initialType, tableformat, gallery_mod
         nodes <- merge(nodes, arguments$nodes[[n]], by=name, all.x=TRUE)
       }
       nodeorder <- unique(nodeorder)
+      check_ids(initialnodes,nodeorder)
       nodeorder <- c(intersect(nodeorder,initialnodes),setdiff(initialnodes,nodeorder))
       for(d in dupnames){
         nodes[[d]] <- NA
@@ -429,10 +462,10 @@ treeGalleryWrapper <- function(tree, deep, initialType, tableformat, gallery_mod
           types <- unique(types)
           types <- types[!is.na(types)]
           gallery$options$nodeTypes <- types
-    }
-
-    if(!is.null(initialType)){
-      gallery$options$initialType <- as.character(initialType)[1]
+          if(is.null(initialType)){
+            initialType <- types[1]
+          }
+          gallery$options$initialType <- as.character(initialType)[1]
     }
   }
 
